==> sdd.creditosimple-0.2.5-sources.jar: ar/com/sdd/creditosimple/core/galicia/CreditoSimpleGaliciaConnector.java <==
package ar.com.sdd.creditosimple.core.galicia;

import ar.com.sdd.commons.rest.core.RestConnector;
import ar.com.sdd.commons.rest.core.RestConnectorEnvironment;
import ar.com.sdd.commons.rest.core.RestConnectorException;
import ar.com.sdd.commons.rest.core.RestSecurityManager;
import ar.com.sdd.creditosimple.io.galicia.*;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

import javax.ws.rs.client.Invocation;
import java.util.HashMap;
import java.util.Map;

public class CreditoSimpleGaliciaConnector implements RestSecurityManager {

    private static final Logger log = LogManager.getLogger(CreditoSimpleGaliciaConnector.class);

    private final RestConnector restConnector;
    private final String appId;
    private final String appKey;


    public CreditoSimpleGaliciaConnector(CreditoSimpleGaliciaConnectorContext context) {
        String baseUrl = context.getBaseUrl();
        appId = context.getAppId();
        appKey = context.getAppKey();

        log.debug("Creando conector para CreditoSimple Galicia con baseUrl [" + baseUrl + "], appId [" + appId + "], appKey [" + appKey + "]");

        RestConnectorEnvironment environment = new RestConnectorEnvironment(baseUrl, null, null, null, null);
        restConnector = new RestConnector(environment, this);

    }

    /**
     * Valida un cuit y devuelve solo 200 si esta bien
     * Si esta erroneo, devueve 500 y el ResponseError.class lleno
     *
     * @param cuit
     * @throws RestConnectorException
     */
    public void getValidarCuit(String cuit) throws RestConnectorException {
        getValidarCuit(cuit, "1");
    }
    public void getValidarCuit(String cuit, String productId) throws RestConnectorException {
        log.debug("[getValidarCuit] Request GET validar con cuit [" + cuit + "]");
        Map<String, Object> templateParameters = new HashMap<>();
        templateParameters.put("cuit", cuit);
        templateParameters.put("productId", productId);
        restConnector.genericGetTextResponse(null, ErrorResponse.class, "/validar/{cuit}/{productId}", templateParameters);
        log.debug("[getValidarCuit] Response GET validar [OK]");
    }


    public ConveniosResponse getConvenios()  throws RestConnectorException {
        return this.getConvenios(null,null,null);
    }
    public ConveniosResponse getConvenios(String cuit, String segmentName, String productId)  throws RestConnectorException {
        log.debug("[getConvenios] Request GET convenios con cuit["+cuit+"]segmentName["+segmentName+"]productId["+productId+"]");
        String path = "/convenios";
        Map<String, Object> templateParameters = new HashMap<>();
        if (productId!=null) {
            templateParameters.put("productId", productId);
            path +="/{productId}";
        }
        //Los queryParameters van distinto. Lo correcto seria que lo resuelva mejor el genericGet.....
        String sep="?";
        if (cuit!=null) {
            path += sep+"cuit="+cuit;
            sep="&";
        }
        if (segmentName!=null) {
            path += sep+"segmentName="+segmentName;
            sep="&";
        }
        ConveniosResponse response = restConnector.genericGet(null, ConveniosResponse.class, ErrorResponse.class, path, templateParameters);
        log.debug("[getConvenios] Response GET convenios [" + response + "]");
        return response;
    }

    public SimulacionResponse postSimulacion(SimulacionRequest simulacionRequest) throws RestConnectorException {
        log.debug("[postSimulacion] Request POST simulacion [" + simulacionRequest + "]");
        String path = "/simulacion";
        SimulacionResponse response = restConnector.genericPost(simulacionRequest, SimulacionResponse.class, ErrorResponse.class, path);
        log.debug("[postSimulacion] Response POST simulacion [" + response + "]");
        return response;
    }

    public OrdenesResponse postOrden(OrdenRequest ordenRequest) throws RestConnectorException {
        log.debug("[postOrden] Request POST orden [" + ordenRequest + "]");
        String path = "/orders";
        OrdenesResponse response = restConnector.genericPost(ordenRequest, OrdenesResponse.class, ErrorResponse.class, path);
        log.debug("[postOrden] Response POST orden [" + response + "]");
        return response;
    }

    public OrdenesResponse getOrdenes() throws RestConnectorException {
        log.debug("[getOrdenes] Request GET ordenes sin parametros");
        String path = "/orders";
        OrdenesResponse response = restConnector.genericGet(null, OrdenesResponse.class, ErrorResponse.class, path);
        log.debug("[getOrdenes] Response GET ordenes [" + response + "]");
        return response;
    }

    public OrdenesResponse getOrden(String idOrden) throws RestConnectorException {
        log.debug("[getOrden] Request GET orden con idOrden [" + idOrden + "]");
        OrdenesResponse response = restConnector.genericGet(null, OrdenesResponse.class, ErrorResponse.class, "/orders/{id_orden}", "id_orden", idOrden);
        log.debug("[getOrden] Response GET orden [" + response + "]");
        return response;
    }



    @Override
    public Invocation.Builder addHeaders(Invocation.Builder builder)  {
        builder.header("app_id", appId);
        builder.header("x-api-key", appKey);
        //Compat TGR:
        //En la version banco galicia, se necesita app_key, en la version Nera x-api-key
        //Inicalmente dejamos las dos , para que sean compatibles las conexiones y poder cambiar solo usanro unaa URL distinta
        //Una vez que este estable la migracio anera se puede borrar la app_key
        builder.header("app_key", appKey);
        return builder;
    }

    @Override
    public boolean getDisableHTTPSErrors() {
        return false;
    }
}

==> sdd.creditosimple-0.2.7-sources.jar: ar/com/sdd/creditosimple/core/galicia/CreditoSimpleGaliciaConnector.java <==
package ar.com.sdd.creditosimple.core.galicia;

import ar.com.sdd.commons.rest.core.RestConnector;
import ar.com.sdd.commons.rest.core.RestConnectorEnvironment;
import ar.com.sdd.commons.rest.core.RestConnectorException;
import ar.com.sdd.commons.rest.core.RestSecurityManager;
import ar.com.sdd.creditosimple.io.galicia.*;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

import javax.ws.rs.client.Invocation;
import java.util.HashMap;
import java.util.Map;

public class CreditoSimpleGaliciaConnector implements RestSecurityManager {

    private static final Logger log = LogManager.getLogger(CreditoSimpleGaliciaConnector.class);

    private final RestConnector restConnector;
    private final String appId;
    private final String appKey;


    public CreditoSimpleGaliciaConnector(CreditoSimpleGaliciaConnectorContext context) {
        String baseUrl = context.getBaseUrl();
        appId = context.getAppId();
        appKey = context.getAppKey();

        log.debug("Creando conector para CreditoSimple Galicia con baseUrl [" + baseUrl + "], appId [" + appId + "], appKey [" + appKey + "]");

        RestConnectorEnvironment environment = new RestConnectorEnvironment(baseUrl, null, null, null, null);
        restConnector = new RestConnector(environment, this);

    }

    /**
     * Valida un cuit y devuelve solo 200 si esta bien
     * Si esta erroneo, devueve 500 y el ResponseError.class lleno
     *
     * @param cuit
     * @throws RestConnectorException
     */
    public void getValidarCuit(String cuit) throws RestConnectorException {
        getValidarCuit(cuit, "1");
    }
    public void getValidarCuit(String cuit, String productId) throws RestConnectorException {
        log.debug("[getValidarCuit] Request GET validar con cuit [" + cuit + "]");
        Map<String, Object> templateParameters = new HashMap<>();
        templateParameters.put("cuit", cuit);
        templateParameters.put("productId", productId);
        restConnector.genericGetTextResponse(null, ErrorResponse.class, "/validar/{cuit}/{productId}", templateParameters);
        log.debug("[getValidarCuit] Response GET validar [OK]");
    }


    public ConveniosResponse getConvenios()  throws RestConnectorException {
        return this.getConvenios(null,null,null);
    }
    public ConveniosResponse getConvenios(String cuit, String segmentName, String productId)  throws RestConnectorException {
        log.debug("[getConvenios] Request GET convenios con cuit["+cuit+"]segment_name["+segmentName+"]productId["+productId+"]");
        String path = "/convenios";
        Map<String, Object> templateParameters = new HashMap<>();
        if (productId!=null && !productId.isEmpty()) {
            templateParameters.put("productId", productId);
            path +="/{productId}";
        }
        //Los queryParameters van distinto. Lo correcto seria que lo resuelva mejor el genericGet.....
        String sep="?";
        if (cuit!=null && !cuit.isEmpty()) {
            path += sep+"cuit="+cuit;
            sep="&";
        }
        if (segmentName!=null && !segmentName.isEmpty()) {
            path += sep+"segment_name="+segmentName;
            sep="&";
        }
        ConveniosResponse response = restConnector.genericGet(null, ConveniosResponse.class, ErrorResponse.class, path, templateParameters);
        log.debug("[getConvenios] Response GET convenios [" + response + "]");
        return response;
    }

    public SimulacionResponse postSimulacion(SimulacionRequest simulacionRequest) throws RestConnectorException {
        log.debug("[postSimulacion] Request POST simulacion [" + simulacionRequest + "]");
        String path = "/simulacion";
        SimulacionResponse response = restConnector.genericPost(simulacionRequest, SimulacionResponse.class, ErrorResponse.class, path);
        log.debug("[postSimulacion] Response POST simulacion [" + response + "]");
        return response;
    }

    public OrdenesResponse postOrden(OrdenRequest ordenRequest) throws RestConnectorException {
        log.debug("[postOrden] Request POST orden [" + ordenRequest + "]");
        String path = "/orders";
        OrdenesResponse response = restConnector.genericPost(ordenRequest, OrdenesResponse.class, ErrorResponse.class, path);
        log.debug("[postOrden] Response POST orden [" + response + "]");
        return response;
    }

    public OrdenesResponse getOrdenes() throws RestConnectorException {
        log.debug("[getOrdenes] Request GET ordenes sin parametros");
        String path = "/orders";
        OrdenesResponse response = restConnector.genericGet(null, OrdenesResponse.class, ErrorResponse.class, path);
        log.debug("[getOrdenes] Response GET ordenes [" + response + "]");
        return response;
    }

    public OrdenesResponse getOrden(String idOrden) throws RestConnectorException {
        log.debug("[getOrden] Request GET orden con idOrden [" + idOrden + "]");
        OrdenesResponse response = restConnector.genericGet(null, OrdenesResponse.class, ErrorResponse.class, "/orders/{id_orden}", "id_orden", idOrden);
        log.debug("[getOrden] Response GET orden [" + response + "]");
        return response;
    }



    @Override
    public Invocation.Builder addHeaders(Invocation.Builder builder)  {
        builder.header("app_id", appId);
        builder.header("x-api-key", appKey);
        //Compat TGR:
        //En la version banco galicia, se necesita app_key, en la version Nera x-api-key
        //Inicalmente dejamos las dos , para que sean compatibles las conexiones y poder cambiar solo usanro unaa URL distinta
        //Una vez que este estable la migracio anera se puede borrar la app_key
        builder.header("app_key", appKey);
        return builder;
    }

    @Override
    public boolean getDisableHTTPSErrors() {
        return false;
    }
}
